__version__ = "0.2.0"


from beet import Context
from beet.contrib.load import load
from bolt import bolt


def beet_default(ctx: Context):
    ctx.require(
        load(
            data_pack={"data/reapermc/modules": "@reapermc/modules"},
        ),
        bolt(entrypoint=["*:main", "reapermc:reaper_cleanup"]),
        "bolt_expressions.plugin",
    )
